@@ -5,9 +5,9 @@ from django.contrib.sites.models import Site
 from django.contrib.syndication.views import Feed
 from django.core.urlresolvers import reverse
 from django.db.models import Q
-from django.utils.translation import ugettext as _, get_language
+from django.utils.translation import get_language, get_language_from_request, ugettext as _
 
-from aldryn_blog.models import Post
+from aldryn_blog.models import Category, Post
 
 
 class LatestEntriesFeed(Feed):
@@ -19,9 +19,9 @@ class LatestEntriesFeed(Feed):
         return _('Blog posts on %(site_name)s') % {'site_name': Site.objects.get_current().name}
 
     def items(self, obj):
-        return Post.published.filter(
-            Q(language=get_language()) | Q(language__isnull=True)
-        ).order_by('-publication_start')[:10]
+        language = get_language()
+        posts = Post.published.filter(Q(language=language) | Q(language__isnull=True))
+        return posts.order_by('-publication_start')[:10]
 
     def item_title(self, item):
         return item.title
@@ -45,7 +45,8 @@ class TagFeed(LatestEntriesFeed):
 class CategoryFeed(LatestEntriesFeed):
 
     def get_object(self, request, category):
-        return category
+        language = get_language_from_request(request, check_path=True)
+        return Category.objects.language(language).get(slug=category)
 
     def items(self, obj):
-        return Post.published.filter(category__slug=obj)[:10]
+        return Post.published.filter(category=obj)[:10]
